<?php
/**
 * The Header: Logo and main menu
 *
 * @package BEAUTIQUE
 * @since BEAUTIQUE 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js<?php
	// Class scheme_xxx need in the <html> as context for the <body>!
	echo ' scheme_' . esc_attr( beautique_get_theme_option( 'color_scheme' ) );
?>">

<head>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php
	if ( function_exists( 'wp_body_open' ) ) {
		wp_body_open();
	} else {
		do_action( 'wp_body_open' );
	}
	do_action( 'beautique_action_before_body' );
	?>

	<div class="<?php echo esc_attr( apply_filters( 'beautique_filter_body_wrap_class', 'body_wrap' ) ); ?>" <?php do_action('beautique_action_body_wrap_attributes'); ?>>

		<?php do_action( 'beautique_action_before_page_wrap' ); ?>

		<div class="<?php echo esc_attr( apply_filters( 'beautique_filter_page_wrap_class', 'page_wrap' ) ); ?>" <?php do_action('beautique_action_page_wrap_attributes'); ?>>

			<?php do_action( 'beautique_action_page_wrap_start' ); ?>

			<?php
			$beautique_full_post_loading = ( beautique_is_singular( 'post' ) || beautique_is_singular( 'attachment' ) ) && beautique_get_value_gp( 'action' ) == 'full_post_loading';
			$beautique_prev_post_loading = ( beautique_is_singular( 'post' ) || beautique_is_singular( 'attachment' ) ) && beautique_get_value_gp( 'action' ) == 'prev_post_loading';

			// Don't display the header elements while actions 'full_post_loading' and 'prev_post_loading'
			if ( ! $beautique_full_post_loading && ! $beautique_prev_post_loading ) {

				// Short links to fast access to the content, sidebar and footer from the keyboard
				?>
				<a class="beautique_skip_link skip_to_content_link" href="#content_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'beautique_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to content", 'beautique' ); ?></a>
				<?php if ( beautique_sidebar_present() ) { ?>
				<a class="beautique_skip_link skip_to_sidebar_link" href="#sidebar_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'beautique_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to sidebar", 'beautique' ); ?></a>
				<?php } ?>
				<a class="beautique_skip_link skip_to_footer_link" href="#footer_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'beautique_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to footer", 'beautique' ); ?></a>

				<?php
				do_action( 'beautique_action_before_header' );

				// Header
				$beautique_header_type = beautique_get_theme_option( 'header_type' );
				if ( 'custom' == $beautique_header_type && ! beautique_is_layouts_available() ) {
					$beautique_header_type = 'default';
				}
				get_template_part( apply_filters( 'beautique_filter_get_template_part', "templates/header-" . sanitize_file_name( $beautique_header_type ) ) );

				// Side menu
				if ( in_array( beautique_get_theme_option( 'menu_side' ), array( 'left', 'right' ) ) ) {
					get_template_part( apply_filters( 'beautique_filter_get_template_part', 'templates/header-navi-side' ) );
				}

				// Mobile menu
				get_template_part( apply_filters( 'beautique_filter_get_template_part', 'templates/header-navi-mobile' ) );

				do_action( 'beautique_action_after_header' );

			}
			?>

			<?php do_action( 'beautique_action_before_page_content_wrap' ); ?>

			<div class="page_content_wrap<?php
				if ( beautique_is_off( beautique_get_theme_option( 'remove_margins' ) ) ) {
					if ( empty( $beautique_header_type ) ) {
						$beautique_header_type = beautique_get_theme_option( 'header_type' );
					}
					if ( 'custom' == $beautique_header_type && beautique_is_layouts_available() ) {
						$beautique_header_id = beautique_get_custom_header_id();
						if ( $beautique_header_id > 0 ) {
							$beautique_header_meta = beautique_get_custom_layout_meta( $beautique_header_id );
							if ( ! empty( $beautique_header_meta['margin'] ) ) {
								?> page_content_wrap_custom_header_margin<?php
							}
						}
					}
					$beautique_footer_type = beautique_get_theme_option( 'footer_type' );
					if ( 'custom' == $beautique_footer_type && beautique_is_layouts_available() ) {
						$beautique_footer_id = beautique_get_custom_footer_id();
						if ( $beautique_footer_id ) {
							$beautique_footer_meta = beautique_get_custom_layout_meta( $beautique_footer_id );
							if ( ! empty( $beautique_footer_meta['margin'] ) ) {
								?> page_content_wrap_custom_footer_margin<?php
							}
						}
					}
				}
				do_action( 'beautique_action_page_content_wrap_class', $beautique_prev_post_loading );
				?>"<?php
				if ( apply_filters( 'beautique_filter_is_prev_post_loading', $beautique_prev_post_loading ) ) {
					?> data-single-style="<?php echo esc_attr( beautique_get_theme_option( 'single_style' ) ); ?>"<?php
				}
				do_action( 'beautique_action_page_content_wrap_data', $beautique_prev_post_loading );
			?>>
				<?php
				do_action( 'beautique_action_page_content_wrap', $beautique_full_post_loading || $beautique_prev_post_loading );

				// Single posts banner
				if ( apply_filters( 'beautique_filter_single_post_header', beautique_is_singular( 'post' ) || beautique_is_singular( 'attachment' ) ) ) {
					if ( $beautique_prev_post_loading ) {
						if ( beautique_get_theme_option( 'posts_navigation_scroll_which_block' ) != 'article' ) {
							do_action( 'beautique_action_between_posts' );
						}
					}
					// Single post thumbnail and title
					$beautique_path = apply_filters( 'beautique_filter_get_template_part', 'templates/single-styles/' . beautique_get_theme_option( 'single_style' ) );
					if ( beautique_get_file_dir( $beautique_path . '.php' ) != '' ) {
						get_template_part( $beautique_path );
					}
				}

				// Widgets area above page
				$beautique_body_style   = beautique_get_theme_option( 'body_style' );
				$beautique_widgets_name = beautique_get_theme_option( 'widgets_above_page' );
				$beautique_show_widgets = ! beautique_is_off( $beautique_widgets_name ) && is_active_sidebar( $beautique_widgets_name );
				if ( $beautique_show_widgets ) {
					if ( 'fullscreen' != $beautique_body_style ) {
						?>
						<div class="content_wrap">
							<?php
					}
					beautique_create_widgets_area( 'widgets_above_page' );
					if ( 'fullscreen' != $beautique_body_style ) {
						?>
						</div>
						<?php
					}
				}

				// Content area
				do_action( 'beautique_action_before_content_wrap' );
				?>
				<div class="content_wrap<?php echo 'fullscreen' == $beautique_body_style ? '_fullscreen' : ''; ?>">

					<?php do_action( 'beautique_action_content_wrap_start' ); ?>

					<div class="content">
						<?php
						do_action( 'beautique_action_page_content_start' );

						// Skip link anchor to fast access to the content from keyboard
						?>
						<a id="content_skip_link_anchor" class="beautique_skip_link_anchor" href="#"></a>
						<?php
						// Single posts banner between prev/next posts
						if ( ( beautique_is_singular( 'post' ) || beautique_is_singular( 'attachment' ) )
							&& $beautique_prev_post_loading 
							&& beautique_get_theme_option( 'posts_navigation_scroll_which_block' ) == 'article'
						) {
							do_action( 'beautique_action_between_posts' );
						}

						// Widgets area above content
						beautique_create_widgets_area( 'widgets_above_content' );

						do_action( 'beautique_action_page_content_start_text' );
