<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: //codex.wordpress.org/Template_Hierarchy
 *
 * @package BEAUTIQUE
 * @since BEAUTIQUE 1.0
 */

$beautique_template = apply_filters( 'beautique_filter_get_template_part', beautique_blog_archive_get_template() );

if ( ! empty( $beautique_template ) && 'index' != $beautique_template ) {

	get_template_part( $beautique_template );

} else {

	beautique_storage_set( 'blog_archive', true );

	get_header();

	if ( have_posts() ) {

		// Query params
		$beautique_stickies   = is_home()
								|| ( in_array( beautique_get_theme_option( 'post_type' ), array( '', 'post' ) )
									&& (int) beautique_get_theme_option( 'parent_cat' ) == 0
									)
										? get_option( 'sticky_posts' )
										: false;
		$beautique_post_type  = beautique_get_theme_option( 'post_type' );
		$beautique_args       = array(
								'blog_style'     => beautique_get_theme_option( 'blog_style' ),
								'post_type'      => $beautique_post_type,
								'taxonomy'       => beautique_get_post_type_taxonomy( $beautique_post_type ),
								'parent_cat'     => beautique_get_theme_option( 'parent_cat' ),
								'posts_per_page' => beautique_get_theme_option( 'posts_per_page' ),
								'sticky'         => beautique_get_theme_option( 'sticky_style' ) == 'columns'
															&& is_array( $beautique_stickies )
															&& count( $beautique_stickies ) > 0
															&& get_query_var( 'paged' ) < 1
								);

		beautique_blog_archive_start();

		do_action( 'beautique_action_blog_archive_start' );

		if ( is_author() ) {
			do_action( 'beautique_action_before_page_author' );
			get_template_part( apply_filters( 'beautique_filter_get_template_part', 'templates/author-page' ) );
			do_action( 'beautique_action_after_page_author' );
		}

		if ( beautique_get_theme_option( 'show_filters' ) ) {
			do_action( 'beautique_action_before_page_filters' );
			beautique_show_filters( $beautique_args );
			do_action( 'beautique_action_after_page_filters' );
		} else {
			do_action( 'beautique_action_before_page_posts' );
			beautique_show_posts( array_merge( $beautique_args, array( 'cat' => $beautique_args['parent_cat'] ) ) );
			do_action( 'beautique_action_after_page_posts' );
		}

		do_action( 'beautique_action_blog_archive_end' );

		beautique_blog_archive_end();

	} else {

		if ( is_search() ) {
			get_template_part( apply_filters( 'beautique_filter_get_template_part', 'templates/content', 'none-search' ), 'none-search' );
		} else {
			get_template_part( apply_filters( 'beautique_filter_get_template_part', 'templates/content', 'none-archive' ), 'none-archive' );
		}
	}

	get_footer();
}
