<?php
/**
 * The Sidebar containing the main widget areas.
 *
 * @package BEAUTIQUE
 * @since BEAUTIQUE 1.0
 */

if ( beautique_sidebar_present() ) {
	
	$beautique_sidebar_type = beautique_get_theme_option( 'sidebar_type' );
	if ( 'custom' == $beautique_sidebar_type && ! beautique_is_layouts_available() ) {
		$beautique_sidebar_type = 'default';
	}
	
	// Catch output to the buffer
	ob_start();
	if ( 'default' == $beautique_sidebar_type ) {
		// Default sidebar with widgets
		$beautique_sidebar_name = beautique_get_theme_option( 'sidebar_widgets' );
		beautique_storage_set( 'current_sidebar', 'sidebar' );
		if ( is_active_sidebar( $beautique_sidebar_name ) ) {
			dynamic_sidebar( $beautique_sidebar_name );
		}
	} else {
		// Custom sidebar from Layouts Builder
		$beautique_sidebar_id = beautique_get_custom_sidebar_id();
		do_action( 'beautique_action_show_layout', $beautique_sidebar_id );
	}
	$beautique_out = trim( ob_get_contents() );
	ob_end_clean();
	
	// If any html is present - display it
	if ( ! empty( $beautique_out ) ) {
		$beautique_sidebar_position    = beautique_get_theme_option( 'sidebar_position' );
		$beautique_sidebar_position_ss = beautique_get_theme_option( 'sidebar_position_ss' );
		?>
		<div class="sidebar widget_area
			<?php
			echo ' ' . esc_attr( $beautique_sidebar_position );
			echo ' sidebar_' . esc_attr( $beautique_sidebar_position_ss );
			echo ' sidebar_' . esc_attr( $beautique_sidebar_type );

			$beautique_sidebar_scheme = apply_filters( 'beautique_filter_sidebar_scheme', beautique_get_theme_option( 'sidebar_scheme' ) );
			if ( ! empty( $beautique_sidebar_scheme ) && ! beautique_is_inherit( $beautique_sidebar_scheme ) && 'custom' != $beautique_sidebar_type ) {
				echo ' scheme_' . esc_attr( $beautique_sidebar_scheme );
			}
			?>
		" role="complementary">
			<?php

			// Skip link anchor to fast access to the sidebar from keyboard
			?>
			<a id="sidebar_skip_link_anchor" class="beautique_skip_link_anchor" href="#"></a>
			<?php

			do_action( 'beautique_action_before_sidebar_wrap', 'sidebar' );

			// Button to show/hide sidebar on mobile
			if ( in_array( $beautique_sidebar_position_ss, array( 'above', 'float' ) ) ) {
				$beautique_title = apply_filters( 'beautique_filter_sidebar_control_title', 'float' == $beautique_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'beautique' ) : '' );
				$beautique_text  = apply_filters( 'beautique_filter_sidebar_control_text', 'above' == $beautique_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'beautique' ) : '' );
				?>
				<a href="#" class="sidebar_control" title="<?php echo esc_attr( $beautique_title ); ?>"><?php echo esc_html( $beautique_text ); ?></a>
				<?php
			}
			?>
			<div class="sidebar_inner">
				<?php
				do_action( 'beautique_action_before_sidebar', 'sidebar' );
				beautique_show_layout( preg_replace( "/<\/aside>[\r\n\s]*<aside/", '</aside><aside', $beautique_out ) );
				do_action( 'beautique_action_after_sidebar', 'sidebar' );
				?>
			</div>
			<?php

			do_action( 'beautique_action_after_sidebar_wrap', 'sidebar' );

			?>
		</div>
		<div class="clearfix"></div>
		<?php
	}
}
