<?php
/**
 * Skin Setup
 *
 * @package BEAUTIQUE
 * @since BEAUTIQUE 1.76.0
 */


//--------------------------------------------
// SKIN DEFAULTS
//--------------------------------------------

// Return theme's (skin's) default value for the specified parameter
if ( ! function_exists( 'beautique_theme_defaults' ) ) {
	function beautique_theme_defaults( $name='', $value='' ) {
		$defaults = array(
			'page_width'          => 1290,
			'page_boxed_extra'  => 60,
			'page_fullwide_max' => 1920,
			'page_fullwide_extra' => 60,
			'sidebar_width'       => 410,
			'sidebar_gap'       => 40,
			'grid_gap'          => 30,
			'rad'               => 0
		);
		if ( empty( $name ) ) {
			return $defaults;
		} else {
			if ( $value === '' && isset( $defaults[ $name ] ) ) {
				$value = $defaults[ $name ];
			}
			return $value;
		}
	}
}


// WOOCOMMERCE SETUP
//--------------------------------------------------

// Allow extended layouts for WooCommerce
if ( ! function_exists( 'beautique_skin_woocommerce_allow_extensions' ) ) {
	add_filter( 'beautique_filter_load_woocommerce_extensions', 'beautique_skin_woocommerce_allow_extensions' );
	function beautique_skin_woocommerce_allow_extensions( $allow ) {
		return true;
	}
}


// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)


//--------------------------------------------
// SKIN SETTINGS
//--------------------------------------------
if ( ! function_exists( 'beautique_skin_setup' ) ) {
	add_action( 'after_setup_theme', 'beautique_skin_setup', 1 );
	function beautique_skin_setup() {

		$GLOBALS['BEAUTIQUE_STORAGE'] = array_merge( $GLOBALS['BEAUTIQUE_STORAGE'], array(

			// Key validator: market[env|loc]-vendor[axiom|ancora|themerex]
			'theme_pro_key'       => 'env-axiom',

			'theme_doc_url'       => '//doc.themerex.net/beautique/',

			'theme_demofiles_url' => '//demofiles.axiomthemes.com/beautique/',

			'theme_rate_url'      => '//themeforest.net/downloads',

			'theme_custom_url'    => '//themerex.net/offers/?utm_source=offers&utm_medium=click&utm_campaign=themeinstall',

			'theme_support_url'   => '//themerex.net/support/',

			'theme_download_url'  => '//themeforest.net/user/axiomthemes/portfolio',         			// Axiom

			'theme_video_url'     => '//www.youtube.com/channel/UCdIjRh7-lPVHqTTKpaf8PLA',   			// Axiom

			'theme_privacy_url'   => '//axiomthemes.com/privacy-policy/',                    			// Axiom

			'portfolio_url'       => '//themeforest.net/user/axiomthemes/portfolio',         			// Axiom

			// Comma separated slugs of theme-specific categories (for get relevant news in the dashboard widget)
			// (i.e. 'children,kindergarten')
			'theme_categories'    => '',
		) );
	}
}


// Add/remove/change Theme Settings
if ( ! function_exists( 'beautique_skin_setup_settings' ) ) {
	add_action( 'after_setup_theme', 'beautique_skin_setup_settings', 1 );
	function beautique_skin_setup_settings() {
		// Example: enable (true) / disable (false) thumbs in the prev/next navigation
		beautique_storage_set_array( 'settings', 'thumbs_in_navigation', false );
		beautique_storage_set_array2( 'required_plugins', 'woocommerce', 'install', true );
		beautique_storage_set_array2( 'required_plugins', 'ti-woocommerce-wishlist', 'install', true );
		beautique_storage_set_array2( 'required_plugins', 'woo-smart-quick-view', 'install', true );
		beautique_storage_set_array2( 'required_plugins', 'elegro-payment', 'install', true );
	}
}



//--------------------------------------------
// SKIN FONTS
//--------------------------------------------
if ( ! function_exists( 'beautique_skin_setup_fonts' ) ) {
	add_action( 'after_setup_theme', 'beautique_skin_setup_fonts', 1 );
	function beautique_skin_setup_fonts() {
		// Fonts to load when theme start
		// It can be:
		// - Google fonts (specify name, family and styles)
		// - Adobe fonts (specify name, family and link URL)
		// - uploaded fonts (specify name, family), placed in the folder css/font-face/font-name inside the skin folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		// example: font name 'TeX Gyre Termes', folder 'TeX-Gyre-Termes'
		beautique_storage_set(
			'load_fonts', array(
                array(
                    'name'   => 'Bebas Neue',
                    'family' => 'cursive',
                    'link'   => '',
                    'styles' => 'ital,wght@0,400;1,400',
                ),
                array(
                    'name'   => 'Roboto',
                    'family' => 'sans-serif',
                    'link'   => '',
                    'styles' => 'ital,wght@0,100;0,300;0,400;0,500;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900',
                ),
			)
		);

		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		beautique_storage_set( 'load_fonts_subset', 'latin,latin-ext' );

		// Settings of the main tags.
		// Default value of 'font-family' may be specified as reference to the array $load_fonts (see above)
		// or as comma-separated string.
		// In the second case (if 'font-family' is specified manually as comma-separated string):
		//    1) Font name with spaces in the parameter 'font-family' will be enclosed in the quotes and no spaces after comma!
		//    2) If font-family inherit a value from the 'Main text' - specify 'inherit' as a value
		// example:
		// Correct:   'font-family' => beautique_get_load_fonts_family_string( $load_fonts[0] )
		// Correct:   'font-family' => 'Roboto,sans-serif'
		// Correct:   'font-family' => '"PT Serif",sans-serif'
		// Incorrect: 'font-family' => 'Roboto, sans-serif'
		// Incorrect: 'font-family' => 'PT Serif,sans-serif'

		$font_description = esc_html__( 'Font settings for the %s of the site. To ensure that the elements scale properly on mobile devices, please use only the following units: "rem", "em" or "ex"', 'beautique' );

		beautique_storage_set(
			'theme_fonts', array(
				'p'       => array(
					'title'           => esc_html__( 'Main text', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'main text', 'beautique' ) ),
					'font-family'     => 'Roboto,sans-serif',
					'font-size'       => '1rem',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.7em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0em',
					'margin-bottom'   => '1.8em',
				),
				'post'    => array(
					'title'           => esc_html__( 'Article text', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'article text', 'beautique' ) ),
					'font-family'     => '',			// Example: '"PR Serif",serif',
					'font-size'       => '',			// Example: '1.286rem',
					'font-weight'     => '',			// Example: '400',
					'font-style'      => '',			// Example: 'normal',
					'line-height'     => '',			// Example: '1.75em',
					'text-decoration' => '',			// Example: 'none',
					'text-transform'  => '',			// Example: 'none',
					'letter-spacing'  => '',			// Example: '',
					'margin-top'      => '',			// Example: '0em',
					'margin-bottom'   => '',			// Example: '1.4em',
				),
				'h1'      => array(
					'title'           => esc_html__( 'Heading 1', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H1', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '3.353em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.14em',
					'margin-bottom'   => '0.38em',
				),
				'h2'      => array(
					'title'           => esc_html__( 'Heading 2', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H2', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '2.765em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.021em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0.75px',
					'margin-top'      => '0.84em',
					'margin-bottom'   => '0.4em',
				),
				'h3'      => array(
					'title'           => esc_html__( 'Heading 3', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H3', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '2.059em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.086em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0.5px',
					'margin-top'      => '1.18em',
					'margin-bottom'   => '0.55em',
				),
				'h4'      => array(
					'title'           => esc_html__( 'Heading 4', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H4', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '1.647em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.214em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0.55px',
					'margin-top'      => '1.45em',
					'margin-bottom'   => '0.58em',
				),
				'h5'      => array(
					'title'           => esc_html__( 'Heading 5', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H5', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '1.412em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.208em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0.58px',
					'margin-top'      => '1.57em',
					'margin-bottom'   => '0.75em',
				),
				'h6'      => array(
					'title'           => esc_html__( 'Heading 6', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H6', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '1.118em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.474em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0.35px',
					'margin-top'      => '2.4em',
					'margin-bottom'   => '1.1em',
				),
				'logo'    => array(
					'title'           => esc_html__( 'Logo text', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'text of the logo', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '1.5em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.25em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'button'  => array(
					'title'           => esc_html__( 'Buttons', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'buttons', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '18px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '21px',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
				),
				'input'   => array(
					'title'           => esc_html__( 'Input fields', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'input fields, dropdowns and textareas', 'beautique' ) ),
					'font-family'     => 'Roboto,sans-serif',
					'font-size'       => '15px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',     // Attention! Firefox don't allow line-height less then 1.5em in the select
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'info'    => array(
					'title'           => esc_html__( 'Post meta', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'post meta (author, categories, publish date, counters, share, etc.)', 'beautique' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '13px',  // Old value '13px' don't allow using 'font zoom' in the custom blog items
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.4em',
					'margin-bottom'   => '',
				),
				'menu'    => array(
					'title'           => esc_html__( 'Main menu', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'main menu items', 'beautique' ) ),
					'font-family'     => '"Bebas Neue",cursive',
					'font-size'       => '18px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
				),
				'submenu' => array(
					'title'           => esc_html__( 'Dropdown menu', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'dropdown menu items', 'beautique' ) ),
					'font-family'     => 'Roboto,sans-serif',
					'font-size'       => '14px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'other' => array(
					'title'           => esc_html__( 'Other', 'beautique' ),
					'description'     => sprintf( $font_description, esc_html__( 'specific elements', 'beautique' ) ),
					'font-family'     => 'Roboto,sans-serif',
				),
			)
		);

		// Font presets
		beautique_storage_set(
			'font_presets', array(
				'karla' => array(
				'title'  => esc_html__( 'Karla', 'beautique' ),
				'load_fonts' => array(
				// Google font
					array(
						'name'   => 'Dancing Script',
						'family' => 'fantasy',
						'link'   => '',
						'styles' => '300,400,700',
					),
					// Google font
					array(
						'name'   => 'Sansita Swashed',
						'family' => 'fantasy',
						'link'   => '',
						'styles' => '300,400,700',
					),
				),
				'theme_fonts' => array(
					'p'       => array(
						'font-family'     => '"Dancing Script",fantasy',
						'font-size'       => '1.25rem',
					),
					'post'    => array(
						'font-family'     => '',
					),
					'h1'      => array(
						'font-family'     => '"Sansita Swashed",fantasy',
						'font-size'       => '4em',
					),
					'h2'      => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
					'h3'      => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
					'h4'      => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
					'h5'      => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
					'h6'      => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
					'logo'    => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
					'button'  => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
					'input'   => array(
						'font-family'     => 'inherit',
					),
					'info'    => array(
						'font-family'     => 'inherit',
					),
					'menu'    => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
					'submenu' => array(
						'font-family'     => '"Sansita Swashed",fantasy',
					),
				),
			),
				'roboto' => array(
				'title'  => esc_html__( 'Roboto', 'beautique' ),
				'load_fonts' => array(
					// Google font
					array(
						'name'   => 'Noto Sans JP',
						'family' => 'serif',
						'link'   => '',
						'styles' => '300,300italic,400,400italic,700,700italic',
					),
					// Google font
					array(
						'name'   => 'Merriweather',
						'family' => 'sans-serif',
						'link'   => '',
						'styles' => '300,300italic,400,400italic,700,700italic',
					),
					),
					'theme_fonts' => array(
					'p'       => array(
						'font-family'     => '"Noto Sans JP",serif',
					),
					'post'    => array(
						'font-family'     => '',
					),
					'h1'      => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'h2'      => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'h3'      => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'h4'      => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'h5'      => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'h6'      => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'logo'    => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'button'  => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'input'   => array(
						'font-family'     => 'inherit',
					),
					'info'    => array(
						'font-family'     => 'inherit',
					),
					'menu'    => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
					'submenu' => array(
						'font-family'     => 'Merriweather,sans-serif',
					),
				),
			),
				'garamond' => array(
				'title'  => esc_html__( 'Garamond', 'beautique' ),
				'load_fonts' => array(
					// Adobe font
					array(
						'name'   => 'Europe',
						'family' => 'sans-serif',
						'link'   => 'https://use.typekit.net/qmj1tmx.css',
						'styles' => '',
					),
					// Adobe font
					array(
						'name'   => 'Sofia Pro',
						'family' => 'sans-serif',
						'link'   => 'https://use.typekit.net/qmj1tmx.css',
						'styles' => '',
					),
				),
				'theme_fonts' => array(
					'p'       => array(
						'font-family'     => '"Sofia Pro",sans-serif',
					),
					'post'    => array(
						'font-family'     => '',
					),
					'h1'      => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'h2'      => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'h3'      => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'h4'      => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'h5'      => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'h6'      => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'logo'    => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'button'  => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'input'   => array(
						'font-family'     => 'inherit',
					),
					'info'    => array(
						'font-family'     => 'inherit',
					),
					'menu'    => array(
						'font-family'     => 'Europe,sans-serif',
					),
					'submenu' => array(
						'font-family'     => 'Europe,sans-serif',
					),
				),
			),
		)
		);
	}
}


//--------------------------------------------
// COLOR SCHEMES
//--------------------------------------------
if ( ! function_exists( 'beautique_skin_setup_schemes' ) ) {
	add_action( 'after_setup_theme', 'beautique_skin_setup_schemes', 1 );
	function beautique_skin_setup_schemes() {

		// Theme colors for customizer
		// Attention! Inner scheme must be last in the array below
		beautique_storage_set(
			'scheme_color_groups', array(
				'main'    => array(
					'title'       => esc_html__( 'Main', 'beautique' ),
					'description' => esc_html__( 'Colors of the main content area', 'beautique' ),
				),
				'alter'   => array(
					'title'       => esc_html__( 'Alter', 'beautique' ),
					'description' => esc_html__( 'Colors of the alternative blocks (sidebars, etc.)', 'beautique' ),
				),
				'extra'   => array(
					'title'       => esc_html__( 'Extra', 'beautique' ),
					'description' => esc_html__( 'Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'beautique' ),
				),
				'inverse' => array(
					'title'       => esc_html__( 'Inverse', 'beautique' ),
					'description' => esc_html__( 'Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'beautique' ),
				),
				'input'   => array(
					'title'       => esc_html__( 'Input', 'beautique' ),
					'description' => esc_html__( 'Colors of the form fields (text field, textarea, select, etc.)', 'beautique' ),
				),
			)
		);

		beautique_storage_set(
			'scheme_color_names', array(
				'bg_color'    => array(
					'title'       => esc_html__( 'Background color', 'beautique' ),
					'description' => esc_html__( 'Background color of this block in the normal state', 'beautique' ),
				),
				'bg_hover'    => array(
					'title'       => esc_html__( 'Background hover', 'beautique' ),
					'description' => esc_html__( 'Background color of this block in the hovered state', 'beautique' ),
				),
				'bd_color'    => array(
					'title'       => esc_html__( 'Border color', 'beautique' ),
					'description' => esc_html__( 'Border color of this block in the normal state', 'beautique' ),
				),
				'bd_hover'    => array(
					'title'       => esc_html__( 'Border hover', 'beautique' ),
					'description' => esc_html__( 'Border color of this block in the hovered state', 'beautique' ),
				),
				'text'        => array(
					'title'       => esc_html__( 'Text', 'beautique' ),
					'description' => esc_html__( 'Color of the text inside this block', 'beautique' ),
				),
				'text_dark'   => array(
					'title'       => esc_html__( 'Text dark', 'beautique' ),
					'description' => esc_html__( 'Color of the dark text (bold, header, etc.) inside this block', 'beautique' ),
				),
				'text_light'  => array(
					'title'       => esc_html__( 'Text light', 'beautique' ),
					'description' => esc_html__( 'Color of the light text (post meta, etc.) inside this block', 'beautique' ),
				),
				'text_link'   => array(
					'title'       => esc_html__( 'Link', 'beautique' ),
					'description' => esc_html__( 'Color of the links inside this block', 'beautique' ),
				),
				'text_hover'  => array(
					'title'       => esc_html__( 'Link hover', 'beautique' ),
					'description' => esc_html__( 'Color of the hovered state of links inside this block', 'beautique' ),
				),
				'text_link2'  => array(
					'title'       => esc_html__( 'Accent 2', 'beautique' ),
					'description' => esc_html__( 'Color of the accented texts (areas) inside this block', 'beautique' ),
				),
				'text_hover2' => array(
					'title'       => esc_html__( 'Accent 2 hover', 'beautique' ),
					'description' => esc_html__( 'Color of the hovered state of accented texts (areas) inside this block', 'beautique' ),
				),
				'text_link3'  => array(
					'title'       => esc_html__( 'Accent 3', 'beautique' ),
					'description' => esc_html__( 'Color of the other accented texts (buttons) inside this block', 'beautique' ),
				),
				'text_hover3' => array(
					'title'       => esc_html__( 'Accent 3 hover', 'beautique' ),
					'description' => esc_html__( 'Color of the hovered state of other accented texts (buttons) inside this block', 'beautique' ),
				),
			)
		);

		// Default values for each color scheme
		$schemes = array(

			// Color scheme: 'default'
			'default' => array(
				'title'    => esc_html__( 'Default', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FFFFFF',
					'bd_color'         => '#F3DCD1',

					// Text and links colors
					'text'             => '#787370',
					'text_light'       => '#9A9A9A',
					'text_dark'        => '#101010',
					'text_link'        => '#FF9C65',
					'text_hover'       => '#EF8144',
					'text_link2'       => '#E2AFCF',
					'text_hover2'      => '#CF8CB6',
					'text_link3'       => '#9AC8E8',
					'text_hover3'      => '#7EB3D8',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FFF4EE',
					'alter_bg_hover'   => '#FBE8DE',
					'alter_bd_color'   => '#F3DCD1',
					'alter_bd_hover'   => '#B8CAD2',
					'alter_text'       => '#787370',
					'alter_light'      => '#9A9A9A',
					'alter_dark'       => '#101010',
					'alter_link'       => '#FF9C65',
					'alter_hover'      => '#EF8144',
					'alter_link2'      => '#E2AFCF',
					'alter_hover2'     => '#CF8CB6',
					'alter_link3'      => '#9AC8E8',
					'alter_hover3'     => '#7EB3D8',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#202020',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#A1968F',
					'extra_light'      => '#7B706A',
					'extra_dark'       => '#FFFFFF',
					'extra_link'       => '#FF9C65',
					'extra_hover'      => '#FFFFFF',
					'extra_link2'      => '#E2AFCF',
					'extra_hover2'     => '#CF8CB6',
					'extra_link3'      => '#9AC8E8',
					'extra_hover3'     => '#7EB3D8',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#F3DCD1',
					'input_bd_hover'   => '#B8CAD2',
					'input_text'       => '#787370',
					'input_light'      => '#9A9A9A',
					'input_dark'       => '#101010',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#101010',
					'inverse_light'    => '#9A9A9A',
					'inverse_dark'     => '#101010',
					'inverse_link'     => '#FFFFFF',
					'inverse_hover'    => '#FFFFFF',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'dark'
			'dark'    => array(
				'title'    => esc_html__( 'Dark', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#232220',
					'bd_color'         => '#313131',

					// Text and links colors
					'text'             => '#A1968F',
					'text_light'       => '#7B706A',
					'text_dark'        => '#FCFCFC',
					'text_link'        => '#FF9C65',
					'text_hover'       => '#EF8144',
					'text_link2'       => '#E2AFCF',
					'text_hover2'      => '#CF8CB6',
					'text_link3'       => '#9AC8E8',
					'text_hover3'      => '#7EB3D8',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#151218',
					'alter_bg_hover'   => '#201D23',
					'alter_bd_color'   => '#313131',
					'alter_bd_hover'   => '#3F424A',
					'alter_text'       => '#A1968F',
					'alter_light'      => '#7B706A',
					'alter_dark'       => '#FCFCFC',
					'alter_link'       => '#FF9C65',
					'alter_hover'      => '#EF8144',
					'alter_link2'      => '#E2AFCF',
					'alter_hover2'     => '#CF8CB6',
					'alter_link3'      => '#9AC8E8',
					'alter_hover3'     => '#7EB3D8',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#202020',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#A1968F',
					'extra_light'      => '#7B706A',
					'extra_dark'       => '#FFFFFF',
					'extra_link'       => '#FF9C65',
					'extra_hover'      => '#FFFFFF',
					'extra_link2'      => '#E2AFCF', 
					'extra_hover2'     => '#CF8CB6', 
					'extra_link3'      => '#9AC8E8', 
					'extra_hover3'     => '#7EB3D8', 

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#313131',
					'input_bd_hover'   => '#3F424A',
					'input_text'       => '#A1968F',
					'input_light'      => '#7B706A',
					'input_dark'       => '#FFFFFF',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#FFFFFF',
					'inverse_light'    => '#9A9A9A',
					'inverse_dark'     => '#101010',
					'inverse_link'     => '#FFFFFF',
					'inverse_hover'    => '#101010',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'light'
			'light' => array(
				'title'    => esc_html__( 'Light', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FFF4EE',
					'bd_color'         => '#F3DCD1',

					// Text and links colors
					'text'             => '#787370',
					'text_light'       => '#9A9A9A',
					'text_dark'        => '#101010',
					'text_link'        => '#FF9C65',
					'text_hover'       => '#EF8144',
					'text_link2'       => '#E2AFCF',
					'text_hover2'      => '#CF8CB6',
					'text_link3'       => '#9AC8E8',
					'text_hover3'      => '#7EB3D8',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FFFFFF',
					'alter_bg_hover'   => '#FBE8DE',
					'alter_bd_color'   => '#F3DCD1',
					'alter_bd_hover'   => '#B8CAD2',
					'alter_text'       => '#787370',
					'alter_light'      => '#9A9A9A',
					'alter_dark'       => '#101010',
					'alter_link'       => '#FF9C65',
					'alter_hover'      => '#EF8144',
					'alter_link2'      => '#E2AFCF',
					'alter_hover2'     => '#CF8CB6',
					'alter_link3'      => '#9AC8E8',
					'alter_hover3'     => '#7EB3D8',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#202020',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#A1968F',
					'extra_light'      => '#7B706A',
					'extra_dark'       => '#FFFFFF',
					'extra_link'       => '#FF9C65',
					'extra_hover'      => '#FFFFFF',
					'extra_link2'      => '#E2AFCF',
					'extra_hover2'     => '#CF8CB6',
					'extra_link3'      => '#9AC8E8',
					'extra_hover3'     => '#7EB3D8',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#F3DCD1',
					'input_bd_hover'   => '#B8CAD2',
					'input_text'       => '#787370',
					'input_light'      => '#9A9A9A',
					'input_dark'       => '#101010',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#101010',
					'inverse_light'    => '#9A9A9A',
					'inverse_dark'     => '#101010',
					'inverse_link'     => '#FFFFFF',
					'inverse_hover'    => '#FFFFFF',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'red_default'
			'red_default' => array(
				'title'    => esc_html__( 'Red Default', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FFFFFF',
					'bd_color'         => '#DDDDDD',

					// Text and links colors
					'text'             => '#919191',
					'text_light'       => '#AFAFAF',
					'text_dark'        => '#111111',
					'text_link'        => '#FF4624',
					'text_hover'       => '#E32401',
					'text_link2'       => '#FCAC35',
					'text_hover2'      => '#E89418',
					'text_link3'       => '#B29BD9',
					'text_hover3'      => '#9576C8',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F5F5F5',
					'alter_bg_hover'   => '#EFEFEF',
					'alter_bd_color'   => '#DDDDDD',
					'alter_bd_hover'   => '#B8CAD2',
					'alter_text'       => '#919191',
					'alter_light'      => '#AFAFAF',
					'alter_dark'       => '#111111',
					'alter_link'       => '#FF4624',
					'alter_hover'      => '#E32401',
					'alter_link2'      => '#FCAC35',
					'alter_hover2'     => '#E89418',
					'alter_link3'      => '#B29BD9',
					'alter_hover3'     => '#9576C8',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1A1A',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#2E2E2E',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#C2C2C2',
					'extra_light'      => '#646464',
					'extra_dark'       => '#FFFFFF',
					'extra_link'       => '#FF4624',
					'extra_hover'      => '#FFFFFF',
					'extra_link2'      => '#FCAC35',
					'extra_hover2'     => '#E89418',
					'extra_link3'      => '#B29BD9',
					'extra_hover3'     => '#9576C8',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#DDDDDD',
					'input_bd_hover'   => '#B8CAD2',
					'input_text'       => '#919191',
					'input_light'      => '#AFAFAF',
					'input_dark'       => '#111111',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#111111',
					'inverse_light'    => '#AFAFAF',
					'inverse_dark'     => '#111111',
					'inverse_link'     => '#FFFFFF',
					'inverse_hover'    => '#FFFFFF',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'red_dark'
			'red_dark'    => array(
				'title'    => esc_html__( 'Red Dark', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#0D0D0D',
					'bd_color'         => '#2E2E2E',

					// Text and links colors
					'text'             => '#C2C2C2',
					'text_light'       => '#646464',
					'text_dark'        => '#FCFCFC',
					'text_link'        => '#FF4624',
					'text_hover'       => '#E32401',
					'text_link2'       => '#FCAC35',
					'text_hover2'      => '#E89418',
					'text_link3'       => '#B29BD9',
					'text_hover3'      => '#9576C8',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#212121',
					'alter_bg_hover'   => '#111111',
					'alter_bd_color'   => '#2E2E2E',
					'alter_bd_hover'   => '#3F424A',
					'alter_text'       => '#C2C2C2',
					'alter_light'      => '#646464',
					'alter_dark'       => '#FCFCFC',
					'alter_link'       => '#FF4624',
					'alter_hover'      => '#E32401',
					'alter_link2'      => '#FCAC35',
					'alter_hover2'     => '#E89418',
					'alter_link3'      => '#B29BD9',
					'alter_hover3'     => '#9576C8',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1A1A',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#2E2E2E',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#C2C2C2',
					'extra_light'      => '#646464',
					'extra_dark'       => '#FFFFFF',
					'extra_link'       => '#FF4624',
					'extra_hover'      => '#FFFFFF',
					'extra_link2'      => '#FCAC35', 
					'extra_hover2'     => '#E89418', 
					'extra_link3'      => '#B29BD9', 
					'extra_hover3'     => '#9576C8', 

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#2E2E2E',
					'input_bd_hover'   => '#3F424A',
					'input_text'       => '#C2C2C2',
					'input_light'      => '#646464',
					'input_dark'       => '#FFFFFF',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#FFFFFF',
					'inverse_light'    => '#AFAFAF',
					'inverse_dark'     => '#111111',
					'inverse_link'     => '#FFFFFF',
					'inverse_hover'    => '#111111',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'red_light'
			'red_light' => array(
				'title'    => esc_html__( 'Red Light', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F5F5F5',
					'bd_color'         => '#DDDDDD',

					// Text and links colors
					'text'             => '#919191',
					'text_light'       => '#AFAFAF',
					'text_dark'        => '#111111',
					'text_link'        => '#FF4624',
					'text_hover'       => '#E32401',
					'text_link2'       => '#FCAC35',
					'text_hover2'      => '#E89418',
					'text_link3'       => '#B29BD9',
					'text_hover3'      => '#9576C8',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FFFFFF',
					'alter_bg_hover'   => '#EFEFEF',
					'alter_bd_color'   => '#DDDDDD',
					'alter_bd_hover'   => '#B8CAD2',
					'alter_text'       => '#919191',
					'alter_light'      => '#AFAFAF',
					'alter_dark'       => '#111111',
					'alter_link'       => '#FF4624',
					'alter_hover'      => '#E32401',
					'alter_link2'      => '#FCAC35',
					'alter_hover2'     => '#E89418',
					'alter_link3'      => '#B29BD9',
					'alter_hover3'     => '#9576C8',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1A1A',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#2E2E2E',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#C2C2C2',
					'extra_light'      => '#646464',
					'extra_dark'       => '#FFFFFF',
					'extra_link'       => '#FF4624',
					'extra_hover'      => '#FFFFFF',
					'extra_link2'      => '#FCAC35',
					'extra_hover2'     => '#E89418',
					'extra_link3'      => '#B29BD9',
					'extra_hover3'     => '#9576C8',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#DDDDDD',
					'input_bd_hover'   => '#B8CAD2',
					'input_text'       => '#919191',
					'input_light'      => '#AFAFAF',
					'input_dark'       => '#111111',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#111111',
					'inverse_light'    => '#AFAFAF',
					'inverse_dark'     => '#111111',
					'inverse_link'     => '#FFFFFF',
					'inverse_hover'    => '#FFFFFF',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'brown_default'
			'brown_default' => array(
				'title'    => esc_html__( 'Brown Default', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FFFFFF',
					'bd_color'         => '#E4E4E4',

					// Text and links colors
					'text'             => '#7D7D7D',
					'text_light'       => '#A7A6A6',
					'text_dark'        => '#1C1B1B',
					'text_link'        => '#AA8170',
					'text_hover'       => '#8E604D',
					'text_link2'       => '#8E4F4F',
					'text_hover2'      => '#7D3535',
					'text_link3'       => '#4A6E55',
					'text_hover3'      => '#30563C',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F6F6F6',
					'alter_bg_hover'   => '#E9E9E9',
					'alter_bd_color'   => '#E4E4E4',
					'alter_bd_hover'   => '#B8CAD2',
					'alter_text'       => '#7D7D7D',
					'alter_light'      => '#A7A6A6',
					'alter_dark'       => '#1C1B1B',
					'alter_link'       => '#AA8170',
					'alter_hover'      => '#8E604D',
					'alter_link2'      => '#8E4F4F',
					'alter_hover2'     => '#7D3535',
					'alter_link3'      => '#4A6E55',
					'alter_hover3'     => '#30563C',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#171717',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#3A373D',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#AFAEAD',
					'extra_light'      => '#84786B',
					'extra_dark'       => '#D5CDC4',
					'extra_link'       => '#AA8170',
					'extra_hover'      => '#D5CDC4',
					'extra_link2'      => '#8E4F4F',
					'extra_hover2'     => '#7D3535',
					'extra_link3'      => '#4A6E55',
					'extra_hover3'     => '#30563C',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#E4E4E4',
					'input_bd_hover'   => '#B8CAD2',
					'input_text'       => '#7D7D7D',
					'input_light'      => '#A7A6A6',
					'input_dark'       => '#1C1B1B',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1C1B1B',
					'inverse_light'    => '#A7A6A6',
					'inverse_dark'     => '#1C1B1B',
					'inverse_link'     => '#D5CDC4',
					'inverse_hover'    => '#D5CDC4',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'brown_dark'
			'brown_dark'    => array(
				'title'    => esc_html__( 'Brown Dark', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#1B1A1C',
					'bd_color'         => '#3A373D', 

					// Text and links colors
					'text'             => '#AFAEAD',
					'text_light'       => '#84786B',
					'text_dark'        => '#D5CDC4',
					'text_link'        => '#AA8170',
					'text_hover'       => '#8E604D',
					'text_link2'       => '#8E4F4F',
					'text_hover2'      => '#7D3535',
					'text_link3'       => '#4A6E55',
					'text_hover3'      => '#30563C',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#1F1E20',
					'alter_bg_hover'   => '#2B2A2D',
					'alter_bd_color'   => '#3A373D',
					'alter_bd_hover'   => '#3F424A',
					'alter_text'       => '#AFAEAD',
					'alter_light'      => '#84786B',
					'alter_dark'       => '#D5CDC4',
					'alter_link'       => '#AA8170',
					'alter_hover'      => '#8E604D',
					'alter_link2'      => '#8E4F4F',
					'alter_hover2'     => '#7D3535',
					'alter_link3'      => '#4A6E55',
					'alter_hover3'     => '#30563C',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#171717',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#3A373D',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#AFAEAD',
					'extra_light'      => '#84786B',
					'extra_dark'       => '#D5CDC4',
					'extra_link'       => '#AA8170',
					'extra_hover'      => '#D5CDC4',
					'extra_link2'      => '#8E4F4F', 
					'extra_hover2'     => '#7D3535', 
					'extra_link3'      => '#4A6E55', 
					'extra_hover3'     => '#30563C', 

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#3A373D',
					'input_bd_hover'   => '#3F424A',
					'input_text'       => '#AFAEAD',
					'input_light'      => '#84786B',
					'input_dark'       => '#D5CDC4',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#D5CDC4',
					'inverse_light'    => '#A7A6A6',
					'inverse_dark'     => '#1C1B1B',
					'inverse_link'     => '#D5CDC4',
					'inverse_hover'    => '#1C1B1B',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'brown_light'
			'brown_light' => array(
				'title'    => esc_html__( 'Brown Light', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F6F6F6',
					'bd_color'         => '#E4E4E4',

					// Text and links colors
					'text'             => '#7D7D7D',
					'text_light'       => '#A7A6A6',
					'text_dark'        => '#1C1B1B',
					'text_link'        => '#AA8170',
					'text_hover'       => '#8E604D',
					'text_link2'       => '#8E4F4F',
					'text_hover2'      => '#7D3535',
					'text_link3'       => '#4A6E55',
					'text_hover3'      => '#30563C',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FFFFFF',
					'alter_bg_hover'   => '#E9E9E9',
					'alter_bd_color'   => '#E4E4E4',
					'alter_bd_hover'   => '#B8CAD2',
					'alter_text'       => '#7D7D7D',
					'alter_light'      => '#A7A6A6',
					'alter_dark'       => '#1C1B1B',
					'alter_link'       => '#AA8170',
					'alter_hover'      => '#8E604D',
					'alter_link2'      => '#8E4F4F',
					'alter_hover2'     => '#7D3535',
					'alter_link3'      => '#4A6E55',
					'alter_hover3'     => '#30563C',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#171717',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#3A373D',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#AFAEAD',
					'extra_light'      => '#84786B',
					'extra_dark'       => '#D5CDC4',
					'extra_link'       => '#AA8170',
					'extra_hover'      => '#FFFFFF',
					'extra_link2'      => '#D5CDC4',
					'extra_hover2'     => '#7D3535',
					'extra_link3'      => '#4A6E55',
					'extra_hover3'     => '#30563C',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#E4E4E4',
					'input_bd_hover'   => '#B8CAD2',
					'input_text'       => '#7D7D7D',
					'input_light'      => '#A7A6A6',
					'input_dark'       => '#1C1B1B',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1C1B1B',
					'inverse_light'    => '#A7A6A6',
					'inverse_dark'     => '#1C1B1B',
					'inverse_link'     => '#D5CDC4',
					'inverse_hover'    => '#D5CDC4',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'green_default'
			'green_default' => array(
				'title'    => esc_html__( 'Green Default', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F6F3E9',
					'bd_color'         => '#CFCCBF',

					// Text and links colors
					'text'             => '#72716B',
					'text_light'       => '#B4B0A5',
					'text_dark'        => '#040403',
					'text_link'        => '#487254',
					'text_hover'       => '#325D3E',
					'text_link2'       => '#4C7891',
					'text_hover2'      => '#3B6881',
					'text_link3'       => '#914C68',
					'text_hover3'      => '#853757',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#E9E4D3',
					'alter_bg_hover'   => '#E5DFCA',
					'alter_bd_color'   => '#CFCCBF',
					'alter_bd_hover'   => '#B8CAD2',
					'alter_text'       => '#72716B',
					'alter_light'      => '#B4B0A5',
					'alter_dark'       => '#040403',
					'alter_link'       => '#487254',
					'alter_hover'      => '#325D3E',
					'alter_link2'      => '#4C7891',
					'alter_hover2'     => '#3B6881',
					'alter_link3'      => '#914C68',
					'alter_hover3'     => '#853757',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#100D0D',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#3A3833',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#BEBBB4',
					'extra_light'      => '#757267',
					'extra_dark'       => '#FCFCFC',
					'extra_link'       => '#487254',
					'extra_hover'      => '#FCFCFC',
					'extra_link2'      => '#4C7891',
					'extra_hover2'     => '#3B6881',
					'extra_link3'      => '#914C68',
					'extra_hover3'     => '#853757',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#CFCCBF',
					'input_bd_hover'   => '#B8CAD2',
					'input_text'       => '#72716B',
					'input_light'      => '#B4B0A5',
					'input_dark'       => '#040403',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#040403',
					'inverse_light'    => '#B4B0A5',
					'inverse_dark'     => '#040403',
					'inverse_link'     => '#FCFCFC',
					'inverse_hover'    => '#FCFCFC',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'green_dark'
			'green_dark'    => array(
				'title'    => esc_html__( 'Green Dark', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#161513',
					'bd_color'         => '#3A3833',

					// Text and links colors
					'text'             => '#BEBBB4',
					'text_light'       => '#757267',
					'text_dark'        => '#FCFCFC',
					'text_link'        => '#487254',
					'text_hover'       => '#325D3E',
					'text_link2'       => '#4C7891',
					'text_hover2'      => '#3B6881',
					'text_link3'       => '#914C68',
					'text_hover3'      => '#853757',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#201E19', 
					'alter_bg_hover'   => '#292621',
					'alter_bd_color'   => '#3A3833',
					'alter_bd_hover'   => '#3A3833',
					'alter_text'       => '#BEBBB4',
					'alter_light'      => '#757267',
					'alter_dark'       => '#FCFCFC',
					'alter_link'       => '#487254',
					'alter_hover'      => '#325D3E',
					'alter_link2'      => '#4C7891',
					'alter_hover2'     => '#3B6881',
					'alter_link3'      => '#914C68',
					'alter_hover3'     => '#853757',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#100D0D',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#3A3833',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#BEBBB4',
					'extra_light'      => '#757267',
					'extra_dark'       => '#FCFCFC',
					'extra_link'       => '#487254',
					'extra_hover'      => '#FCFCFC',
					'extra_link2'      => '#4C7891', 
					'extra_hover2'     => '#3B6881', 
					'extra_link3'      => '#914C68', 
					'extra_hover3'     => '#853757', 

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#3A3833',
					'input_bd_hover'   => '#3F424A',
					'input_text'       => '#BEBBB4',
					'input_light'      => '#757267',
					'input_dark'       => '#FCFCFC',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#FCFCFC',
					'inverse_light'    => '#B4B0A5',
					'inverse_dark'     => '#040403',
					'inverse_link'     => '#FCFCFC',
					'inverse_hover'    => '#040403',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'green_light'
			'green_light' => array(
				'title'    => esc_html__( 'Green Light', 'beautique' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#E9E4D3', 
					'bd_color'         => '#CFCCBF',

					// Text and links colors
					'text'             => '#72716B',
					'text_light'       => '#B4B0A5',
					'text_dark'        => '#040403',
					'text_link'        => '#487254',
					'text_hover'       => '#325D3E',
					'text_link2'       => '#4C7891',
					'text_hover2'      => '#3B6881',
					'text_link3'       => '#914C68',
					'text_hover3'      => '#853757',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F6F3E9',
					'alter_bg_hover'   => '#E5DFCA',
					'alter_bd_color'   => '#CFCCBF',
					'alter_bd_hover'   => '#B8CAD2',
					'alter_text'       => '#72716B',
					'alter_light'      => '#B4B0A5',
					'alter_dark'       => '#040403',
					'alter_link'       => '#487254',
					'alter_hover'      => '#325D3E',
					'alter_link2'      => '#4C7891',
					'alter_hover2'     => '#3B6881',
					'alter_link3'      => '#914C68',
					'alter_hover3'     => '#853757',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#100D0D',
					'extra_bg_hover'   => '#101521',
					'extra_bd_color'   => '#3A3833',
					'extra_bd_hover'   => '#333844',
					'extra_text'       => '#BEBBB4',
					'extra_light'      => '#757267',
					'extra_dark'       => '#FCFCFC',
					'extra_link'       => '#487254',
					'extra_hover'      => '#FCFCFC',
					'extra_link2'      => '#4C7891',
					'extra_hover2'     => '#3B6881',
					'extra_link3'      => '#914C68',
					'extra_hover3'     => '#853757',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#CFCCBF',
					'input_bd_hover'   => '#B8CAD2',
					'input_text'       => '#72716B',
					'input_light'      => '#B4B0A5',
					'input_dark'       => '#040403',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#040403',
					'inverse_light'    => '#B4B0A5',
					'inverse_dark'     => '#040403',
					'inverse_link'     => '#FCFCFC',
					'inverse_hover'    => '#FCFCFC',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
		);
		beautique_storage_set( 'schemes', $schemes );
		beautique_storage_set( 'schemes_original', $schemes );

		// Add names of additional colors
		//---> For example:
		//---> beautique_storage_set_array( 'scheme_color_names', 'new_color1', array(
		//---> 	'title'       => __( 'New color 1', 'beautique' ),
		//---> 	'description' => __( 'Description of the new color 1', 'beautique' ),
		//---> ) );


		// Additional colors for each scheme
		// Parameters:	'color' - name of the color from the scheme that should be used as source for the transformation
		//				'alpha' - to make color transparent (0.0 - 1.0)
		//				'hue', 'saturation', 'brightness' - inc/dec value for each color's component
		beautique_storage_set(
			'scheme_colors_add', array(
				'bg_color_0'        => array(
					'color' => 'bg_color',
					'alpha' => 0,
				),
				'bg_color_02'       => array(
					'color' => 'bg_color',
					'alpha' => 0.2,
				),
				'bg_color_07'       => array(
					'color' => 'bg_color',
					'alpha' => 0.7,
				),
				'bg_color_08'       => array(
					'color' => 'bg_color',
					'alpha' => 0.8,
				),
				'bg_color_09'       => array(
					'color' => 'bg_color',
					'alpha' => 0.9,
				),
				'alter_bg_color_07' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.7,
				),
				'alter_bg_color_05' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.5,
				),
				'alter_bg_color_04' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.4,
				),
				'alter_bg_color_00' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0,
				),
				'alter_bg_color_02' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.2,
				),
				'alter_bd_color_02' => array(
					'color' => 'alter_bd_color',
					'alpha' => 0.2,
				),
				'alter_dark_015'     => array(
					'color' => 'alter_dark',
					'alpha' => 0.15,
				),
				'alter_dark_02'     => array(
					'color' => 'alter_dark',
					'alpha' => 0.2,
				),
				'alter_dark_05'     => array(
					'color' => 'alter_dark',
					'alpha' => 0.5,
				),
				'alter_dark_08'     => array(
					'color' => 'alter_dark',
					'alpha' => 0.8,
				),
				'alter_link_02'     => array(
					'color' => 'alter_link',
					'alpha' => 0.2,
				),
				'alter_link_07'     => array(
					'color' => 'alter_link',
					'alpha' => 0.7,
				),
				'extra_bg_color_05' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.5,
				),
				'extra_bg_color_07' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.7,
				),
				'extra_link_02'     => array(
					'color' => 'extra_link',
					'alpha' => 0.2,
				),
				'extra_link_07'     => array(
					'color' => 'extra_link',
					'alpha' => 0.7,
				),
				'text_dark_003'      => array(
					'color' => 'text_dark',
					'alpha' => 0.03,
				),
				'text_dark_005'      => array(
					'color' => 'text_dark',
					'alpha' => 0.05,
				),
				'text_dark_008'      => array(
					'color' => 'text_dark',
					'alpha' => 0.08,
				),
				'text_dark_015'      => array(
					'color' => 'text_dark',
					'alpha' => 0.15,
				),
				'text_dark_02'      => array(
					'color' => 'text_dark',
					'alpha' => 0.2,
				),
				'text_dark_03'      => array(
					'color' => 'text_dark',
					'alpha' => 0.3,
				),
				'text_dark_05'      => array(
					'color' => 'text_dark',
					'alpha' => 0.5,
				),
				'text_dark_07'      => array(
					'color' => 'text_dark',
					'alpha' => 0.7,
				),
				'text_dark_08'      => array(
					'color' => 'text_dark',
					'alpha' => 0.8,
				),
				'text_link_007'      => array(
					'color' => 'text_link',
					'alpha' => 0.07,
				),
				'text_link_02'      => array(
					'color' => 'text_link',
					'alpha' => 0.2,
				),
				'text_link_03'      => array(
					'color' => 'text_link',
					'alpha' => 0.3,
				),
				'text_link_04'      => array(
					'color' => 'text_link',
					'alpha' => 0.4,
				),
				'text_link_05'      => array(
					'color' => 'text_link',
					'alpha' => 0.5,
				),
				'text_link_07'      => array(
					'color' => 'text_link',
					'alpha' => 0.7,
				),
				'text_link2_08'      => array(
					'color' => 'text_link2',
					'alpha' => 0.8,
				),
				'text_link2_007'      => array(
					'color' => 'text_link2',
					'alpha' => 0.07,
				),
				'text_link2_02'      => array(
					'color' => 'text_link2',
					'alpha' => 0.2,
				),
				'text_link2_03'      => array(
					'color' => 'text_link2',
					'alpha' => 0.3,
				),
				'text_link2_05'      => array(
					'color' => 'text_link2',
					'alpha' => 0.5,
				),
				'text_link3_007'      => array(
					'color' => 'text_link3',
					'alpha' => 0.07,
				),
				'text_link3_02'      => array(
					'color' => 'text_link3',
					'alpha' => 0.2,
				),
				'text_link3_03'      => array(
					'color' => 'text_link3',
					'alpha' => 0.3,
				),
				'inverse_text_03'      => array(
					'color' => 'inverse_text',
					'alpha' => 0.3,
				),
				'inverse_link_05'      => array(
					'color' => 'inverse_link',
					'alpha' => 0.5,
				),
				'inverse_link_08'      => array(
					'color' => 'inverse_link',
					'alpha' => 0.8,
				),
				'inverse_hover_08'      => array(
					'color' => 'inverse_hover',
					'alpha' => 0.8,
				),
				'text_dark_blend'   => array(
					'color'      => 'text_dark',
					'hue'        => 2,
					'saturation' => -10,
					'brightness' => 10,
				),
				'text_link_blend'   => array(
					'color'      => 'text_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'alter_link_blend'  => array(
					'color'      => 'alter_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
			)
		);

		// Simple scheme editor: lists the colors to edit in the "Simple" mode.
		// For each color you can set the array of 'slave' colors and brightness factors that are used to generate new values,
		// when 'main' color is changed
		// Leave 'slave' arrays empty if your scheme does not have a color dependency
		beautique_storage_set(
			'schemes_simple', array(
				'text_link'        => array(),
				'text_hover'       => array(),
				'text_link2'       => array(),
				'text_hover2'      => array(),
				'text_link3'       => array(),
				'text_hover3'      => array(),
				'alter_link'       => array(),
				'alter_hover'      => array(),
				'alter_link2'      => array(),
				'alter_hover2'     => array(),
				'alter_link3'      => array(),
				'alter_hover3'     => array(),
				'extra_link'       => array(),
				'extra_hover'      => array(),
				'extra_link2'      => array(),
				'extra_hover2'     => array(),
				'extra_link3'      => array(),
				'extra_hover3'     => array(),
			)
		);

		// Parameters to set order of schemes in the css
		beautique_storage_set(
			'schemes_sorted', array(
				'color_scheme',
				'header_scheme',
				'menu_scheme',
				'sidebar_scheme',
				'footer_scheme',
			)
		);

		// Color presets
		beautique_storage_set(
			'color_presets', array(
				'autumn' => array(
				'title'  => esc_html__( 'Autumn', 'beautique' ),
				'colors' => array(
				'default' => array(
					'text_link'  => '#d83938',
					'text_hover' => '#f2b232',
					),
				'dark' => array(
					'text_link'  => '#d83938',
					'text_hover' => '#f2b232',
					)
				)
			),
			'green' => array(
				'title'  => esc_html__( 'Natural Green', 'beautique' ),
				'colors' => array(
					'default' => array(
					'text_link'  => '#75ac78',
					'text_hover' => '#378e6d',
					),
					'dark' => array(
					'text_link'  => '#75ac78',
					'text_hover' => '#378e6d',
					)
				)
			),
		)
		);
	}
}

// Background selection option
// 3 - add/remove Theme Options elements
if ( ! function_exists( 'beautique_clone_skin_theme_setup3' ) ) {
	add_action( 'after_setup_theme', 'beautique_clone_skin_theme_setup3', 3 );
	function beautique_clone_skin_theme_setup3() {
		beautique_storage_set_array_after( 'options', 'remove_margins', array(
				'extra_bg_image' => array(
					"title" => esc_html__('Extra background image', 'beautique'),
					"desc" => wp_kses_data( __('Select or upload background-image to display it in the page. Does not work for boxed body style.', 'beautique') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'beautique')
					),
					'dependency' => array(
						'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
					),
					"std" => '',
					'pro_only'   => BEAUTIQUE_THEME_FREE,
					"type" => "image"
				),
				'extra_bg_image_size' => array(
					"title" => esc_html__('Extra background image size', 'beautique'),
					"desc" => wp_kses_data( __('Use size contain (cover original).', 'beautique') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'beautique')
					),
					'dependency' => array(
						'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
					),
					"std" => 0,
					'pro_only'   => BEAUTIQUE_THEME_FREE,
					"type" => "switch"
				),
				'extra_bg_image_fixed' => array(
					'title' => esc_html__('Extra background attachment', 'beautique'),
					'desc' => wp_kses_data( __('Enable fixed position of the background image', 'beautique') ),
					'std' => 0,
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'beautique')
					),
					'dependency' => array(
						'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
					),
					'pro_only'   => BEAUTIQUE_THEME_FREE,
					'type' => 'switch'
				),
			)
		);
	}
}

// Add div with fixed background
if ( ! function_exists( 'beautique_skin_filter_page_wrap_class' ) ) {
    add_action('beautique_filter_page_wrap_class', 'beautique_skin_filter_page_wrap_class');
    function beautique_skin_filter_page_wrap_class($class) {
        $extra_bg_image = beautique_get_theme_option('extra_bg_image');
        $extra_bg_image_size = beautique_is_on(beautique_get_theme_option('extra_bg_image_size'));
        $extra_bg_image_fixed = beautique_is_on(beautique_get_theme_option('extra_bg_image_fixed'));
        $body_boxed_style = beautique_get_theme_option( 'body_style' ) == 'boxed';
        if (!empty( $extra_bg_image ) && !$body_boxed_style && !$extra_bg_image_fixed) {
            $custom_bg = ' ' . 'with_bg' .($extra_bg_image_size ? ' contain_size ' : ''). ' ' . beautique_add_inline_css_class('background-image: url(' . esc_url($extra_bg_image) . ');');
            $class = $class . $custom_bg;
        } else if (!empty( $extra_bg_image ) && !$body_boxed_style && $extra_bg_image_fixed) {
			$class = $class . ' with_bg_fixed';
		}
        return $class;
    }
}

if ( ! function_exists( 'beautique_skin_custom_bg_layout' ) ) {
    add_action('beautique_action_page_wrap_start', 'beautique_skin_custom_bg_layout');
    function beautique_skin_custom_bg_layout() {
		$extra_bg_image = beautique_get_theme_option('extra_bg_image');
        $extra_bg_image_size = beautique_is_on(beautique_get_theme_option('extra_bg_image_size'));
        $extra_bg_image_fixed = beautique_is_on(beautique_get_theme_option('extra_bg_image_fixed'));
        $body_boxed_style = beautique_get_theme_option( 'body_style' ) == 'boxed';
		if (!empty( $extra_bg_image ) && !$body_boxed_style && $extra_bg_image_fixed) {
            $custom_bg = ($extra_bg_image_size ? ' contain_size ' : ''). ' ' . beautique_add_inline_css_class('background-image: url(' . esc_url($extra_bg_image) . ');');
			?>
				<div class="custom_bg_fixed <?php echo esc_attr($custom_bg); ?>"></div>
			<?php
		}
    }
}

// Enqueue extra styles for frontend
if ( ! function_exists( 'beautique_skin_upgrade_style' ) ) {
	add_action( 'wp_enqueue_scripts', 'beautique_skin_upgrade_style', 2060 );
	function beautique_skin_upgrade_style() {
		$beautique_url = beautique_get_file_url( beautique_skins_get_current_skin_dir() . 'skin-upgrade-style.css' );	
		if ( '' != $beautique_url ) {
			wp_enqueue_style( 'beautique-skin-upgrade-style' . esc_attr( beautique_skins_get_current_skin_name() ), $beautique_url, array(), null );
		}
	}
}

// Add new styles to the Google map
if ( ! function_exists( 'beautique_trx_addons_sc_googlemap_styles2' ) ) {
	add_filter( 'trx_addons_filter_sc_googlemap_styles', 'beautique_trx_addons_sc_googlemap_styles2' );
	function beautique_trx_addons_sc_googlemap_styles2( $list ) {
		$list['modern'] = esc_html__( 'Modern', 'beautique' );
		$list['gray'] = esc_html__( 'Gray', 'beautique' );
		return $list;
	}
}

// Enqueue scripts
if ( ! function_exists( 'beautique_skin_extra_frontend_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'beautique_skin_extra_frontend_scripts', 1100 );
	function beautique_skin_extra_frontend_scripts() {
		$beautique_url = beautique_get_file_url( beautique_skins_get_current_skin_dir() . 'extra.js' );
		if ( '' != $beautique_url ) {
			wp_enqueue_script( 'beautique-extra', $beautique_url, array( 'jquery' ), null, true );
		}
	}
}

// Activation methods
if ( ! function_exists( 'beautique_skin_filter_activation_methods2' ) ) {
    add_filter( 'trx_addons_filter_activation_methods', 'beautique_skin_filter_activation_methods2', 11, 1 );
	function beautique_skin_filter_activation_methods2( $args ) {
		$args['elements_key'] = true;
		return $args;
	}
}