<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package BEAUTIQUE
 * @since BEAUTIQUE 1.0
 */

$beautique_template_args = get_query_var( 'beautique_template_args' );

if ( is_array( $beautique_template_args ) ) {
	$beautique_columns    = empty( $beautique_template_args['columns'] ) ? 2 : max( 1, $beautique_template_args['columns'] );
	$beautique_blog_style = array( $beautique_template_args['type'], $beautique_columns );
    $beautique_columns_class = beautique_get_column_class( 1, $beautique_columns, ! empty( $beautique_template_args['columns_tablet']) ? $beautique_template_args['columns_tablet'] : '', ! empty($beautique_template_args['columns_mobile']) ? $beautique_template_args['columns_mobile'] : '' );
} else {
	$beautique_template_args = array();
	$beautique_blog_style = explode( '_', beautique_get_theme_option( 'blog_style' ) );
	$beautique_columns    = empty( $beautique_blog_style[1] ) ? 2 : max( 1, $beautique_blog_style[1] );
    $beautique_columns_class = beautique_get_column_class( 1, $beautique_columns );
}
$beautique_expanded   = ! beautique_sidebar_present() && beautique_get_theme_option( 'expand_content' ) == 'expand';

$beautique_post_format = get_post_format();
$beautique_post_format = empty( $beautique_post_format ) ? 'standard' : str_replace( 'post-format-', '', $beautique_post_format );

?><div class="<?php
	if ( ! empty( $beautique_template_args['slider'] ) ) {
		echo ' slider-slide swiper-slide';
	} else {
		echo ( beautique_is_blog_style_use_masonry( $beautique_blog_style[0] ) ? 'masonry_item masonry_item-1_' . esc_attr( $beautique_columns ) : esc_attr( $beautique_columns_class ) );
	}
?>"><article id="post-<?php the_ID(); ?>" data-post-id="<?php the_ID(); ?>"
	<?php
	post_class(
		'post_item post_item_container post_format_' . esc_attr( $beautique_post_format )
				. ' post_layout_classic post_layout_classic_' . esc_attr( $beautique_columns )
				. ' post_layout_' . esc_attr( $beautique_blog_style[0] )
				. ' post_layout_' . esc_attr( $beautique_blog_style[0] ) . '_' . esc_attr( $beautique_columns )
	);
	beautique_add_blog_animation( $beautique_template_args );
	?>
>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$beautique_hover      = ! empty( $beautique_template_args['hover'] ) && ! beautique_is_inherit( $beautique_template_args['hover'] )
							? $beautique_template_args['hover']
							: beautique_get_theme_option( 'image_hover' );

	$beautique_components = ! empty( $beautique_template_args['meta_parts'] )
							? ( is_array( $beautique_template_args['meta_parts'] )
								? $beautique_template_args['meta_parts']
								: explode( ',', $beautique_template_args['meta_parts'] )
								)
							: beautique_array_get_keys_by_value( beautique_get_theme_option( 'meta_parts' ) );

	beautique_show_post_featured( apply_filters( 'beautique_filter_args_featured',
		array(
			'thumb_size' => ! empty( $beautique_template_args['thumb_size'] )
				? $beautique_template_args['thumb_size']
				: beautique_get_thumb_size(
					'classic' == $beautique_blog_style[0]
						? ( strpos( beautique_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $beautique_columns > 2 ? 'big' : 'huge' )
								: ( $beautique_columns > 2
									? ( $beautique_expanded ? 'square' : 'square' )
									: ($beautique_columns > 1 ? 'square' : ( $beautique_expanded ? 'huge' : 'big' ))
									)
							)
						: ( strpos( beautique_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $beautique_columns > 2 ? 'masonry-big' : 'full' )
								: ($beautique_columns === 1 ? ( $beautique_expanded ? 'huge' : 'big' ) : ( $beautique_columns <= 2 && $beautique_expanded ? 'masonry-big' : 'masonry' ))
							)
			),
			'hover'      => $beautique_hover,
			'meta_parts' => $beautique_components,
			'no_links'   => ! empty( $beautique_template_args['no_links'] ),
        ),
        'content-classic',
        $beautique_template_args
    ) );

	// Title and post meta
	$beautique_show_title = get_the_title() != '';
	$beautique_show_meta  = count( $beautique_components ) > 0 && ! in_array( $beautique_hover, array( 'border', 'pull', 'slide', 'fade', 'info' ) );

	if ( $beautique_show_title ) {
		?>
		<div class="post_header entry-header">
			<?php

			// Post meta
			if ( apply_filters( 'beautique_filter_show_blog_meta', $beautique_show_meta, $beautique_components, 'classic' ) ) {
				if ( count( $beautique_components ) > 0 ) {
					do_action( 'beautique_action_before_post_meta' );
					beautique_show_post_meta(
						apply_filters(
							'beautique_filter_post_meta_args', array(
							'components' => join( ',', $beautique_components ),
							'seo'        => false,
							'echo'       => true,
						), $beautique_blog_style[0], $beautique_columns
						)
					);
					do_action( 'beautique_action_after_post_meta' );
				}
			}

			// Post title
			if ( apply_filters( 'beautique_filter_show_blog_title', true, 'classic' ) ) {
				do_action( 'beautique_action_before_post_title' );
				if ( empty( $beautique_template_args['no_links'] ) ) {
					the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );
				} else {
					the_title( '<h4 class="post_title entry-title">', '</h4>' );
				}
				do_action( 'beautique_action_after_post_title' );
			}

			if( !in_array( $beautique_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
				// More button
				if ( apply_filters( 'beautique_filter_show_blog_readmore', ! $beautique_show_title || ! empty( $beautique_template_args['more_button'] ), 'classic' ) ) {
					if ( empty( $beautique_template_args['no_links'] ) ) {
						do_action( 'beautique_action_before_post_readmore' );
						beautique_show_post_more_link( $beautique_template_args, '<div class="more-wrap">', '</div>' );
						do_action( 'beautique_action_after_post_readmore' );
					}
				}
			}
			?>
		</div><!-- .entry-header -->
		<?php
	}

	// Post content
	if( in_array( $beautique_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
		ob_start();
		if (apply_filters('beautique_filter_show_blog_excerpt', empty($beautique_template_args['hide_excerpt']) && beautique_get_theme_option('excerpt_length') > 0, 'classic')) {
			beautique_show_post_content($beautique_template_args, '<div class="post_content_inner">', '</div>');
		}
		// More button
		if(! empty( $beautique_template_args['more_button'] )) {
			if ( empty( $beautique_template_args['no_links'] ) ) {
				do_action( 'beautique_action_before_post_readmore' );
				beautique_show_post_more_link( $beautique_template_args, '<div class="more-wrap">', '</div>' );
				do_action( 'beautique_action_after_post_readmore' );
			}
		}
		$beautique_content = ob_get_contents();
		ob_end_clean();
		beautique_show_layout($beautique_content, '<div class="post_content entry-content">', '</div><!-- .entry-content -->');
	}
	?>

</article></div><?php
// Need opening PHP-tag above, because <div> is a inline-block element (used as column)!
